![](../../docs/images/GEFF_HorizontalLogo_RGB.png)

# Graph Exchange File Format Specification

[![License](https://img.shields.io/pypi/l/geff.svg?color=green)](https://github.com/live-image-tracking-tools/geff/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/geff-spec.svg?color=green)](https://pypi.org/project/geff-spec)
[![Python Version](https://img.shields.io/pypi/pyversions/geff-spec.svg?color=green)](https://python.org)

GEFF is a specification for a file format for **exchanging** spatial graph data. It is not intended to be mutable, editable, chunked, or optimized for use in an application setting.

A python library for reading and writing GEFFs can be found [here](https://pypi.org/project/geff) and a java library can be found [here](https://github.com/live-image-tracking-tools/geff-java).

Learn more in the [documentation](https://live-image-tracking-tools.github.io/geff/latest/) or check out the [source code](https://github.com/live-image-tracking-tools/geff).

## Installation

```
pip install geff-spec
```
